/**
Software package to simulate the Tumour--Immune System interaction model
presented in the paper 

"Tumour suppression by Immune System through Stochastic Oscillations"

by G.Caravagna, A.d’Onofrio, P.Milazzo and R.Barbuti.
 
Copyright (C) 2010,  Giulio Caravagna [caravagn@di.unipi.it]

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/


package hsim;

/*
 * Given antigenicity 'c' \in [V1;V2], compute the probability
 * density function for the eradication. Tested values
 * are those starting from V1, reaching V2 and
 * increased by the value delta.
*/
public class AntigenVariation {
	public static void main(String[] args) throws Exception {
		
		double V1 = 0.0;
		double V2 = 0.0;
		double delta = 0.0;

		System.out.println("Stochastic sample size: "
				+ Model.STOCHASTIC_SAMPLE_SIZE);

		double antigenicity = V1;

		int simulation_time = 200;
		int i = 1;
		while (antigenicity < V2)
		{
			System.out.print("Testing antigen value: " + antigenicity);

			String[] param = { "-c", "" + antigenicity, "-TMAX",
					"" + simulation_time };

			Model m = new Model(param);

			// exec Model.STOCHASTIC_SAMPLE_SIZE simulations
			int erad = 0; // # of runs with eradication

			for (int j = 0; j < Model.STOCHASTIC_SAMPLE_SIZE; j++) {
				m = new Model(param);

				// do a single run
				m.simulate();

				// search for eradication instant
				int instant = (int) eradication(m);
				if (instant != -1)
					erad++;
			}

			System.out.println(" [prob. "
					+ (erad / Model.STOCHASTIC_SAMPLE_SIZE) + "]");

			antigenicity += delta;
			i++;
		}

	}

	// look for eradication in the output of the tumor cells
	public static double eradication(Model m) {
		for (int i = 0; i < m.outputT.length; i++) {
			if (m.outputT[i] == 0.0) // found eradication
				return m.outputTime[i]; // return time instant associated
		}

		return -1;
	}

}
