/**
Software package to simulate the Tumour--Immune System interaction model
presented in the paper 

"Tumour suppression by Immune System through Stochastic Oscillations"

by G.Caravagna, A.d’Onofrio, P.Milazzo and R.Barbuti.
 
Copyright (C) 2010,  Giulio Caravagna [caravagn@di.unipi.it]

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/

package hsim;

public class SingleRunModel
{
	public static void main(String[] args) throws Exception 
	{
	    /*
	      Example program running two single stochastic simulations
	      of the model:
	    
	      1] Figure (2,left) c=0.01, TMAX=200
	      2] Figure (2,right) c=0.02, TMAX=200
	    */
	    
	    
	    double c_left = 0.01, c_right = 0.02;

	    int simulation_time = 200;

	    String [] param_left = {"-c", ""+c_left, "-TMAX", ""+simulation_time};
	    String [] param_right = {"-c", ""+c_right, "-TMAX", ""+simulation_time};

	    Model m_left = new Model(param_left);
	    Model m_right = new Model(param_right);
	    
	   
	    System.out.println("\t[Fig.II,left] "+m_left);
	    
	    
	    // do a single run
	    System.out.print("Simulating  ... ");
	    m_left.simulate();
	    System.out.println("OK\n---------");
			
	    // print output
	    for(int i = 0; i < m_left.outputTime.length; i++)
		{
		    System.out.print( m_left.outputTime[i]+"\t"+m_left.outputT[i]+"\t"+m_left.outputE[i]+"\t"+m_left.outputIL[i]+"\n");
		    
		}
	    
	    System.out.println("\n\t[Fig.II,right] "+m_right);
	    
	    
	    // do a single run
	    System.out.print("Simulating  ... ");
	    m_right.simulate();
	    System.out.println("OK\n---------");
			
	    // print output
	    for(int i = 0; i < m_right.outputTime.length; i++)
		{
		    System.out.print( m_right.outputTime[i]+"\t"+m_right.outputT[i]+"\t"+m_right.outputE[i]+"\t"+m_right.outputIL[i]+"\n");
		    
		}
	    
	}
    
}
