/**
Software package to simulate the Tumour--Immune System interaction model
presented in the paper 

"Tumour suppression by Immune System through Stochastic Oscillations"

by G.Caravagna, A.d’Onofrio, P.Milazzo and R.Barbuti.
 
Copyright (C) 2010,  Giulio Caravagna [caravagn@di.unipi.it]

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/

package hsim;

public class Therapy {
	public static void main(String[] args) throws Exception {
		/*
		 * Program running a single stoch. simulation [c=0.0001] 
		 * with therapy diluted in the following way:
		 * 
		 * A) day from 0 to 70 NO THERAPY [s1=0.0]
		 * B) day from 70 to 130 THERAPY  [s1=5400.0]
		 */

		String [] param_A = {"-c", "0.0001", "-TMAX", "70"};
		
		// simulation (A), a model with no therapy
		Model m = new Model(param_A);
		System.out.println("NO THERAPY : Model used " + m);

		// do a single run until day 70
		System.out.print("Simulating days [0-70]... ");
		m.simulate();
		System.out.println("OK\n---------");

		
		// simulation (B), a model with therapy
		String [] param_B = {"-c", "0.0001", "-TMAX", "60"};
		Model m_therapy = new Model(param_B);
		m_therapy.state[0] = m.outputT[m.outputTime.length - 1];
		m_therapy.state[1] = m.outputE[m.outputTime.length - 1];
		m_therapy.state[2] = m.outputIL[m.outputTime.length - 1];
		m_therapy.s1 = 5400;
				
		System.out.println("Model used " + m_therapy);
	
		// do a single run until for the next 60 days
		System.out.print("Simulating days [60-130] s1="+m_therapy.s1+"... ");
		m_therapy.simulate();
		System.out.println("OK\n---------");
		
		// print output
		for (int i = 0; i < m.outputTime.length; i++) {
			System.out.print(m.outputTime[i] + "\t" + m.outputT[i] + "\t"
					+ m.outputE[i] + "\t" + m.outputIL[i] + "\n");
		}
		
		for (int i = 0; i < m_therapy.outputTime.length; i++) {
			System.out.print((m_therapy.outputTime[i] + 70)+ "\t" + m_therapy.outputT[i] + "\t"
					+ m_therapy.outputE[i] + "\t" + m_therapy.outputIL[i] + "\n");
		}
		
		
		
	}

}
